@@ -1,5 +1,7 @@
 test_that("traceback unchanged if no native code", {
   skip_if_not(winch_available())
+  skip_if_not_installed("rlang")
+  skip_if(packageVersion("rlang") >= "1.0.3")
 
   trace <- rlang::trace_back()
   expect_identical(unclass(winch_add_trace_back(trace)), unclass(trace))
